summaryrefslogtreecommitdiffstats
path: root/common/rfb/SMsgHandler.h
diff options
context:
space:
mode:
authorPierre Ossman <ossman@cendio.se>2009-03-20 12:59:05 +0000
committerPierre Ossman <ossman@cendio.se>2009-03-20 12:59:05 +0000
commitc5e25601d923169c30b656246ac503451f04e638 (patch)
tree81b57e582d71eb826f0304047b02d16600a09612 /common/rfb/SMsgHandler.h
parent2a8017db1007977e5353027a9b885495fa7d46d6 (diff)
downloadtigervnc-c5e25601d923169c30b656246ac503451f04e638.tar.gz
tigervnc-c5e25601d923169c30b656246ac503451f04e638.zip
Minimal server side implementation of the extended desktop size protocol.
git-svn-id: svn://svn.code.sf.net/p/tigervnc/code/trunk@3698 3789f03b-4d11-0410-bbf8-ca57d06f2519
Diffstat (limited to 'common/rfb/SMsgHandler.h')
-rw-r--r--common/rfb/SMsgHandler.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/common/rfb/SMsgHandler.h b/common/rfb/SMsgHandler.h
index 50a2dc4d..78cff2f7 100644
--- a/common/rfb/SMsgHandler.h
+++ b/common/rfb/SMsgHandler.h
@@ -38,14 +38,15 @@ namespace rfb {
// The following methods are called as corresponding messages are read. A
// derived class should override these methods as desired. Note that for
// the setPixelFormat() and setEncodings() methods, a derived class must
// call on to SMsgHandler's methods.
virtual void clientInit(bool shared);
virtual void setPixelFormat(const PixelFormat& pf);
virtual void setEncodings(int nEncodings, rdr::U32* encodings);
- virtual void framebufferUpdateRequest(const Rect& r, bool incremental);
+ virtual void framebufferUpdateRequest(const Rect& r, bool incremental) = 0;
+ virtual void setDesktopSize(int fb_width, int fb_height) = 0;
// InputHandler interface
// The InputHandler methods will be called for the corresponding messages.
@@ -38,14 +38,15 @@ namespace rfb {
// The following methods are called as corresponding messages are read. A
// derived class should override these methods as desired. Note that for
- // the setPixelFormat() and setEncodings() methods, a derived class must
- // call on to SMsgHandler's methods.
+ // the setPixelFormat(), setEncodings() and setDesktopSize() methods, a
+ // derived class must call on to SMsgHandler's methods.
virtual void clientInit(bool shared);
virtual void setPixelFormat(const PixelFormat& pf);